@@ -215,9 +215,14 @@ class DSLibrary(object):
         :returns:       A file-like object.
         """
         uri, open_args = self._xlt_resource(resource_name, _mode="inputs" if "r" in mode else "outputs", **kwargs)
-        # remove formatting arguments
+        # remove formatting arguments, etc.
         open_args.pop("format", None)
         open_args.pop("format_options", None)
+        open_args.pop("dask", None)
+        storage_options = open_args.pop("storage_options", None)
+        if storage_options:
+            # for dask read methods we pass these as 'storage_options', everywhere else they are open_args
+            open_args.update(storage_options)
         # send all outputs to mlflow if requested
         use_mlflow = self._mlflow_all and ("w" in mode or "a" in mode)
         if use_mlflow:
@@ -775,6 +780,14 @@ class DSLibrary(object):
             return supplied
         # map requested resource (resource_name) through input spec and override defaults (kwargs)
         uri, open_args = self._xlt_resource(resource_name, **kwargs)
+        # arguments that are specific to load_dataframe() and should not go through to open_resource()
+        fallback_to_text = open_args.pop("fallback_to_text", False)
+        use_dask = open_args.pop("dask", None)
+        format_options = open_args.pop("format_options", None) or {}
+        format = open_args.pop("format", None)
+        if format:
+            format_options = dict(format_options)
+            format_options["format"] = format
         # detect SQL
         if open_args.get("sql") or open_args.get("sql_table"):
             sql = open_args.pop("sql", None)
@@ -801,11 +814,6 @@ class DSLibrary(object):
         file_extension = find_url_extension(uri)
         if not file_extension:
             self._default_format_for_aliases(resource_name, open_args)
-        format_options = open_args.pop("format_options", None) or {}
-        format = open_args.pop("format", None)
-        if format:
-            format_options = dict(format_options)
-            format_options["format"] = format
         # sample-taker
         use_opener = self.open_run_data if open_args.pop("run_data", None) else self.open_resource
         def sampler():
@@ -825,17 +833,16 @@ class DSLibrary(object):
                 return f_r.tell()
         '''
         # sniff format
-        fallback_to_text = open_args.pop("fallback_to_text", False)
         format_info = detect_format(
             uri, sampler=sampler, sizer=None, supplied_options=format_options, fallback_to_text=fallback_to_text
         )
         format = format_info.format
         read_args = format_info.read_args
         # various formats and their read function
-        use_dask = open_args.pop("dask", None)
         if use_dask:
+            use_dask = format in DASK_READ_FORMATS
             read_method = DASK_READ_FORMATS.get(format, PANDAS_READ_FORMATS.get(format))
-            if format == "csv" and format in DASK_READ_FORMATS:
+            if format == "csv" and use_dask:
                 # dask reads 'sample' bytes to determine dtypes, default is 256k, which is often too small
                 #  - 10M is also bound to be too small of course, but it's somewhat less likely
                 if "sample" not in read_args:
@@ -847,6 +854,9 @@ class DSLibrary(object):
         else:
             read_method = PANDAS_READ_FORMATS.get(format)
         if read_method:
+            if use_dask:
+                storage_options = open_args.get("storage_options") or open_args
+                return read_method(uri, storage_options=storage_options, **read_args)
             with use_opener(uri, mode='rb', **open_args) as f_r:
                 if format == "xlsx" and not f_r.seekable():
                     # the XLSX reader requires its stream to be seekable so we download to a temporary file
