@@ -43,6 +43,7 @@ class ModelRunner(object):
         self.outputs = {}
         self.data = {}
         self.parameters = parameters or {}
+        self.code_paths = []
 
     def _to_absolute(self, uri: str):
         """
@@ -115,6 +116,15 @@ class ModelRunner(object):
         self.parameters.update(params)
         return self
 
+    def add_code_path(self, path: str):
+        """
+        Point to a location where import modules might exist.
+        :param path:   Path to a folder containing python code to import from your model.
+        """
+        if path not in self.code_paths:
+            self.code_paths.append(path)
+        return self
+
     def send_metrics_to(self, uri: str=None, mlflow: bool=None, capture: bool=False, **kwargs):
         """
         Determine where metrics will be stored (for read and write).  Parameters are equivalent to set_output(), in
@@ -143,7 +153,8 @@ class ModelRunner(object):
             "entry_point": self.entry_point,
             "inputs": self.inputs,
             "outputs": self.outputs,
-            "parameters": self.parameters
+            "parameters": self.parameters,
+            "code_paths": self.code_paths
         }
         if self.data and local:
             spec["data"] = self.data
