@@ -10,7 +10,7 @@ from collections import namedtuple, defaultdict
 FileFormatDescription = namedtuple("FileFormatDescription", "format read_args size avg_line_size")
 
 # values that are unlikely to be header names, i.e. blank or numeric
-PTN_NOT_HEADER = re.compile(r'^([-+]?(\d+(.\d*)?|.\d+)([eE][-+]?\d+)?)?$')
+PTN_NOT_HEADER = re.compile(r'^([-+]?\s*(\d+(\.\d*)?|\.\d+)([eE][-+]?\d+)?)?$')
 
 
 def detect_format(
@@ -47,7 +47,9 @@ def detect_format(
         "yml": ("yaml", {}),
         "tab": ("csv", {"delimiter": "\t"}),
         "tsv": ("csv", {"delimiter": "\t"}),
+        "txt": ("csv", {"delimiter": '\n', "names": ["line"]})
     }
+    orig_format = (format or "").lower()
     if format:
         format, implied_defaults = FORMAT_ALIASES_ETC.get(format.lower(), (format, {}))    # determine format based on a sample
         read_args.update(implied_defaults)
@@ -55,7 +57,7 @@ def detect_format(
     avg_line_size = None
     # use sample of data if available
     # - some formats are not sniffed so we don't sample them
-    if sampler and format not in ("yaml", "xlsx", "xls", "parquet"):
+    if sampler and format not in ("yaml", "xlsx", "xls", "parquet") and orig_format not in ("txt",):
         sample = sampler() if hasattr(sampler, "__call__") else sampler
         if not format and looks_like_json(sample, size):
             format = "json"
@@ -220,8 +222,6 @@ def apply_json_read_args(sample, read_args):
     lines = [line.strip() for line in sample.strip().split("\n")]
     if partial_line and len(lines) > 2:
         lines = lines[:-1]
-    if len(lines) < 2:
-        return
     # single JSON object or array per line
     if all(line.startswith("{") and line.endswith("}") for line in lines):
         read_args["lines"] = True
@@ -268,6 +268,6 @@ def detect_headerless_csv(sample, read_args):
         cols = re.split(r'\s+', first_line)
     else:
         cols = first_line.split(delim)
-    if all(map(lambda col: PTN_NOT_HEADER.match(col) is not None, cols)):
+    if all(map(lambda col: PTN_NOT_HEADER.match(col), cols)):
         read_args["header"] = None
         read_args["names"] = ["col_%d" % (n+1) for n in range(len(cols))]
