@@ -477,3 +477,29 @@ class TestFront(unittest.TestCase):
         df = MyInst().load_dataframe(fn)
         self.assertEqual(list(df.a), [2, 7])
         self.assertEqual(list(df.b), [5, 9])
+
+    def test_load_dataframe__strip_open_args(self):
+        inst = self
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                inst.assertEqual(path, "x")
+                inst.assertEqual(kwargs, {})
+                return io.StringIO("x\n1\n2")
+        r = MyInst().load_dataframe("x", dask=False, format="csv", format_options={}, fallback_to_text=False)
+        assert list(r.x) == [1, 2]
+
+    def test_load_dataframe__empty_cell_case(self):
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                return io.StringIO("x0,x1\nA,\n,B\nD,C")
+        df = MyInst().load_dataframe("x.csv")
+        self.assertEqual(list(df.fillna(value="").x0), ["A", "", "D"])
+
+    def test_json_case(self):
+        x = '{"uri":"","run_id":"","user":"","time":1634234451.674405098,"name":"x","value":1,"step":0}'
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                return io.StringIO(x)
+        df = MyInst().load_dataframe("x")
+        assert "run_id" in df.columns
+        assert "name" in df.columns
