@@ -2,8 +2,7 @@ import unittest
 import tempfile
 import shutil
 
-from dslibrary.utils.file_utils import FileOpener, connect_to_filesystem, write_stream_with_read_on_close, \
-    find_url_extension
+from dslibrary.utils.file_utils import FileOpener, connect_to_filesystem, write_stream_with_read_on_close
 
 
 class TestFileUtils(unittest.TestCase):
@@ -37,11 +36,3 @@ class TestFileUtils(unittest.TestCase):
         assert fs.exists("x") is True
         assert fs.exists("y") is False
         shutil.rmtree(tmp_f)
-
-    def test_find_url_extension(self):
-        self.assertEqual(find_url_extension("abc.ext"), "ext")
-        self.assertEqual(find_url_extension("abc.Ext"), "ext")
-        self.assertEqual(find_url_extension("abc"), "")
-        self.assertEqual(find_url_extension("http://host/path/filename.ext"), "ext")
-        self.assertEqual(find_url_extension("abc.ext?option=1"), "ext")
-        self.assertEqual(find_url_extension("abc.ext#hash_etc"), "ext")
